<?php
/*
 Plugin Name: VW Preloader
 Plugin URI: https://www.vwthemes.com/
 Description: Add a preloader to any website.
 Author: VW Themes
 Version: 1.0
 Author URI: https://www.vwthemes.com/
 Domain Path: /languages
*/

if (!defined('ABSPATH')) {
    exit; //Exit if accessed directly
}

define( 'VWPL_VERSION', '1.0' );

define( 'VWPL_REQUIRED_WP_VERSION', '5.2.3' );

if ( ! defined( 'VWPL_DIR_URL' ) ){
    define( 'VWPL_DIR_URL', plugin_dir_url( __FILE__ ) );
}

define( 'VWPL_PLUGIN_PATH', plugin_dir_path( __FILE__ ) );

// Loading Translation
if ( ! function_exists ( 'vwpl_plugins_loaded' ) ) {

	function vwpl_plugins_loaded() {
		/* Internationalization */
		load_plugin_textdomain( 'vw-preloader', false, VWPL_DIR_URL . '/languages/' );
	}
}

/*Enqueue Admin Setting Files */
require_once( plugin_dir_path( __FILE__ ).'admin/vwpl-admin-settings.php');

/* Plugin Style And Script */
add_action( 'wp_enqueue_scripts', 'vwpl_style_scripts' );

function vwpl_style_scripts() {

    // Style for front page section
    wp_enqueue_style( 'vwpl-style', VWPL_DIR_URL . 'assets/css/vwpl-style.css');

    // Front end JS
    wp_enqueue_script( 'frontend-js', VWPL_DIR_URL . 'assets/js/front-end.js', array( 'jquery' ) ); 
}

// Color Picker
add_action( 'admin_enqueue_scripts', 'vwpl_color_picker' );

function vwpl_color_picker( $hook ) {
    
 	// Style for dashboard section
 	wp_enqueue_style( 'vwpl-admin-style', VWPL_DIR_URL . 'assets/css/vwpl-admin-style.css');

    // Add the color picker css and js file       
    wp_enqueue_style( 'wp-color-picker' ); 
    wp_enqueue_script( 'wp-color-picker' ); 
     
    // Include our custom jQuery file with WordPress Color Picker dependency
    wp_enqueue_script( 'dynamic-fields-js', VWPL_DIR_URL . 'assets/js/dynamic-fields.js', array( 'jquery' ) ); 
}

/**
 * Preloading Display
 *
 * @param void
 *
 * @return string $output
 */

function vwpl_output() {

    // Globle Variable
    global $vwpl_options;

    // Enable/Disable
    $onoff_enable = $vwpl_options['vwpl_admin_check_enable'];
    if($onoff_enable == 1){  


        $style   = $vwpl_options['vwpl_icon_seleted'];
        $display = $vwpl_options['vwpl_display_option_radio'];
        $background_color = $vwpl_options['vwpl_background_color'];
        
        ?>
        <style type="text/css">
            #vw-preloader-overlay{
                background-color: <?php echo $background_color;  ?> !important;
            }

        </style>
        <?php

        if ( $display == 'home-page' && ( is_home() || is_front_page() ) ) {

            echo '<div id="vw-preloader-overlay" style="<?php echo esc_attr($vwpl_style); ?>"><img src="'.esc_attr( VWPL_DIR_URL ) . 'assets/images/' . $style . '"/></div>';

        } elseif ( $display == 'every-page' ) {

            echo '<div id="vw-preloader-overlay" style="<?php echo esc_attr($vwpl_style); ?>"><img src="'.esc_attr( VWPL_DIR_URL ) . 'assets/images/' . $style . '"/></div>';

        }
    }
}

add_action( 'wp_head', 'vwpl_output', 1000 );

/**
 * Add custom classes to body
 *
 * @since 1.1.2
 *
 * @param array $classes The body classes.
 *
 * @return array $classes The body classes
 */
function vwpl_body_classes( $classes ) {

    // Globle Variable
    global $vwpl_options;

    $display = $vwpl_options['vwpl_display_option_radio'];

    if ( $display == 'home' && ( is_home() || is_front_page() ) ) {
        $classes[] = 'vw-preloader-active';
    } elseif ( $display == 'all' ) {
        $classes[] = 'vw-preloader-active';
    }

    return $classes;
}

add_filter( 'body_class', 'vwpl_body_classes' );